dag_cbor.encoding
=================

.. automodule:: dag_cbor.encoding

EncodableType
-------------

.. autodata:: dag_cbor.encoding.EncodableType

FlatEncodableType
-----------------

.. autodata:: dag_cbor.encoding.FlatEncodableType

encode
------

.. autofunction:: dag_cbor.encoding.encode
